==> segatex-8.500.tar.gz: segatex-8.500/src/seinfo_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEINFOPROCESS_H
#define SEINFOPROCESS_H

#include <qdialog.h>
#include <qlayout.h>
#include <qdir.h> 
#include <qlabel.h> 
#include <q3textedit.h>
#include <q3buttongroup.h>
#include <qradiobutton.h>
//Added by qt3to4:
#include <Q3VBoxLayout>
#include <Q3HBoxLayout>

class SeinfoProcess: public QDialog 
{
	Q_OBJECT
public:
	SeinfoProcess(QWidget *parent = 0, const char *name = 0);
	void seinfo_base_process(QString seinfo_str_pp_str);
public slots:
signals:
protected:
private slots:
	void readFromOutputFile(QString seinfo_str_pp_str);
public:
private:
	QPushButton *closeButton;
	Q3TextEdit *textEdit1;

	Q3VBoxLayout *mainLayout;
	Q3VBoxLayout *upperLayout;
	Q3HBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;
        QString seinfo_str_pp_str_echo;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif

==> segatex-8.600.tar.gz: segatex-8.600/src/seinfo_process.h <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007-2014 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#ifndef SEINFOPROCESS_H
#define SEINFOPROCESS_H

#include <QDialog>
#include <QLayout>
#include <QDir> 
#include <QLabel> 
#include <QTextEdit>
///maybe QGROUPBOX here?
#include <q3buttongroup.h>
#include <QRadioButton>
#include <QVBoxLayout>
#include <QHBoxLayout>

class SeinfoProcess: public QDialog 
{
	Q_OBJECT
public:
	SeinfoProcess(QWidget *parent = 0, const char *name = 0);
	void seinfo_base_process(QString seinfo_str_pp_str);
public slots:
signals:
protected:
private slots:
	void readFromOutputFile(QString seinfo_str_pp_str);
public:
private:
	QPushButton *closeButton;
	QTextEdit *textEdit1;

	QVBoxLayout *mainLayout;
	QVBoxLayout *upperLayout;
	QHBoxLayout *footLayout;

        QDir dir;
        QString path;
        QString name;
        QString dir_name;
        QString forward_slash;
        QString file_interface_name;
        QString line_analized;
        QString outputfile_str;
        QString seinfo_str_pp_str_echo;

        QStringList::Iterator it_d;
        QStringList files;

};

#endif
